@@ -5,7 +5,7 @@ use pest::Parser as P;
 use pest_derive::Parser;
 
 #[derive(GrammarParser, Parser)]
-#[grammar = "../grammar//json.pest"]
+#[grammar = "../grammar/json.pest"]
 struct JSONParser;
 
 #[cfg(test)]
