@@ -5,7 +5,7 @@ use pest::Parser as P;
 use pest_derive::Parser;
 
 #[derive(GrammarParser, Parser)]
-#[grammar = "../grammar//kotlin.pest"]
+#[grammar = "../grammar/kotlin.pest"]
 struct KotlinParser;
 
 #[cfg(test)]
