@@ -3,7 +3,7 @@ use regex::Regex;
 use std::collections::HashMap;
 
 const SPCIAL_PUNCTUATIONS: &str = "[.:]([ ]*)";
-const NORMAL_PUNCTUATIONS: &str = "[,!?~]([ ]*)";
+const NORMAL_PUNCTUATIONS: &str = "[,!?]([ ]*)";
 
 lazy_static! {
     static ref FULLWIDTH_MAPS: HashMap<&'static str, &'static str> = map!(
@@ -12,11 +12,14 @@ lazy_static! {
       ";" => "；",
       ":" => "：",
       "!" => "！",
-      "?" => "？",
-      "~" => "～"
+      "?" => "？"
+    );
+    static ref PUNCTUATION_WITH_LEFT_CJK_RE: Regex = regexp!(
+        "{}{}{}",
+        r"[\p{CJ}\w\d]+",
+        NORMAL_PUNCTUATIONS,
+        r"[\p{CJ}]+"
     );
-    static ref PUNCTUATION_WITH_LEFT_CJK_RE: Regex =
-        regexp!("{}{}", NORMAL_PUNCTUATIONS, r"[\p{CJ}]+");
     static ref PUNCTUATION_WITH_RIGHT_CJK_RE: Regex =
         regexp!("{}{}", r"[\p{CJ}]+", NORMAL_PUNCTUATIONS);
     static ref PUNCTUATION_WITH_SPEICAL_CJK_RE: Regex =
@@ -31,12 +34,6 @@ lazy_static! {
 pub fn fullwidth(text: &str) -> String {
     let mut out = String::from(text);
 
-    out = PUNCTUATION_WITH_LEFT_CJK_RE
-        .replace_all(&out, |cap: &regex::Captures| {
-            fullwidth_replace_part(&cap[0])
-        })
-        .to_string();
-
     out = PUNCTUATION_WITH_LEFT_CJK_RE
         .replace_all(&out, |cap: &regex::Captures| {
             fullwidth_replace_part(&cap[0])
@@ -88,10 +85,11 @@ mod tests {
     fn test_fullwidth() {
         let cases = map!(
           "你好,这是一个句子." => "你好，这是一个句子。",
+          "!开头不处理." => "!开头不处理。",
           "刚刚买了一部 iPhone,好开心!" => "刚刚买了一部 iPhone，好开心！",
           "蚂蚁集团上市后有多大的上涨空间?" =>  "蚂蚁集团上市后有多大的上涨空间？",
           "我们需要一位熟悉 JavaScript、HTML5,至少理解一种框架 (如 Backbone.js、AngularJS、React 等) 的前端开发者." => "我们需要一位熟悉 JavaScript、HTML5，至少理解一种框架 (如 Backbone.js、AngularJS、React 等) 的前端开发者。",
-          "蚂蚁疾奔:蚂蚁集团两地上市~全速推进!" =>                                                        "蚂蚁疾奔：蚂蚁集团两地上市～全速推进！",
+          "蚂蚁疾奔:蚂蚁集团两地上市~全速推进!" =>                                                        "蚂蚁疾奔：蚂蚁集团两地上市~全速推进！",
           "蚂蚁集团是阿里巴巴 (BABA.N) 旗下金融科技子公司" =>                                                "蚂蚁集团是阿里巴巴 (BABA.N) 旗下金融科技子公司",
           "Dollar 的演示 $阿里巴巴.US$ 股票标签" =>                                                   "Dollar 的演示 $阿里巴巴.US$ 股票标签",
           "确保&quot;&gt;HTML Entity&lt;&quot;的字符&#34;不会被处理&#34; Ruby&amp;Go" => "确保&quot;&gt;HTML Entity&lt;&quot;的字符&#34;不会被处理&#34; Ruby&amp;Go"
